[rename] Photo ID -> Identification Document
diff --git a/erpnext/hr/doctype/photo_id_type/__init__.py b/erpnext/hr/doctype/identification_document_type/__init__.py
similarity index 100%
rename from erpnext/hr/doctype/photo_id_type/__init__.py
rename to erpnext/hr/doctype/identification_document_type/__init__.py
diff --git a/erpnext/hr/doctype/photo_id_type/photo_id_type.js b/erpnext/hr/doctype/identification_document_type/identification_document_type.js
similarity index 74%
rename from erpnext/hr/doctype/photo_id_type/photo_id_type.js
rename to erpnext/hr/doctype/identification_document_type/identification_document_type.js
index 8779275..351cf9d 100644
--- a/erpnext/hr/doctype/photo_id_type/photo_id_type.js
+++ b/erpnext/hr/doctype/identification_document_type/identification_document_type.js
@@ -1,7 +1,7 @@
 // Copyright (c) 2018, Frappe Technologies Pvt. Ltd. and contributors
 // For license information, please see license.txt
 
-frappe.ui.form.on('Photo ID Type', {
+frappe.ui.form.on('Identification Document Type', {
 	refresh: function(frm) {
 
 	}
diff --git a/erpnext/hr/doctype/photo_id_type/photo_id_type.json b/erpnext/hr/doctype/identification_document_type/identification_document_type.json
similarity index 87%
rename from erpnext/hr/doctype/photo_id_type/photo_id_type.json
rename to erpnext/hr/doctype/identification_document_type/identification_document_type.json
index 616659f..33cbde7 100644
--- a/erpnext/hr/doctype/photo_id_type/photo_id_type.json
+++ b/erpnext/hr/doctype/identification_document_type/identification_document_type.json
@@ -3,7 +3,7 @@
  "allow_guest_to_view": 0, 
  "allow_import": 0, 
  "allow_rename": 0, 
- "autoname": "field:photo_id_type", 
+ "autoname": "field:identification_document_type", 
  "beta": 0, 
  "creation": "2018-05-15 07:13:28.620570", 
  "custom": 0, 
@@ -19,7 +19,7 @@
    "bold": 0, 
    "collapsible": 0, 
    "columns": 0, 
-   "fieldname": "photo_id_type", 
+   "fieldname": "identification_document_type", 
    "fieldtype": "Data", 
    "hidden": 0, 
    "ignore_user_permissions": 0, 
@@ -28,7 +28,7 @@
    "in_global_search": 0, 
    "in_list_view": 0, 
    "in_standard_filter": 0, 
-   "label": "Photo ID Type", 
+   "label": "Identification Document Type", 
    "length": 0, 
    "no_copy": 0, 
    "permlevel": 0, 
@@ -55,10 +55,10 @@
  "issingle": 0, 
  "istable": 0, 
  "max_attachments": 0, 
- "modified": "2018-05-15 07:13:43.616618", 
+ "modified": "2018-05-16 04:34:00.448680", 
  "modified_by": "Administrator", 
  "module": "HR", 
- "name": "Photo ID Type", 
+ "name": "Identification Document Type", 
  "name_case": "", 
  "owner": "Administrator", 
  "permissions": [
diff --git a/erpnext/hr/doctype/photo_id_type/photo_id_type.py b/erpnext/hr/doctype/identification_document_type/identification_document_type.py
similarity index 84%
rename from erpnext/hr/doctype/photo_id_type/photo_id_type.py
rename to erpnext/hr/doctype/identification_document_type/identification_document_type.py
index a41da8d..d9d81d2 100644
--- a/erpnext/hr/doctype/photo_id_type/photo_id_type.py
+++ b/erpnext/hr/doctype/identification_document_type/identification_document_type.py
@@ -6,5 +6,5 @@
 import frappe
 from frappe.model.document import Document
 
-class PhotoIDType(Document):
+class IdentificationDocumentType(Document):
 	pass
diff --git a/erpnext/hr/doctype/photo_id_type/test_photo_id_type.py b/erpnext/hr/doctype/identification_document_type/test_identification_document_type.py
similarity index 76%
rename from erpnext/hr/doctype/photo_id_type/test_photo_id_type.py
rename to erpnext/hr/doctype/identification_document_type/test_identification_document_type.py
index 9e06a67..1265afa 100644
--- a/erpnext/hr/doctype/photo_id_type/test_photo_id_type.py
+++ b/erpnext/hr/doctype/identification_document_type/test_identification_document_type.py
@@ -6,5 +6,5 @@
 import frappe
 import unittest
 
-class TestPhotoIDType(unittest.TestCase):
+class TestIdentificationDocumentType(unittest.TestCase):
 	pass
diff --git a/erpnext/hr/doctype/travel_request/travel_request.json b/erpnext/hr/doctype/travel_request/travel_request.json
index 0c131c5..2f22bbc 100644
--- a/erpnext/hr/doctype/travel_request/travel_request.json
+++ b/erpnext/hr/doctype/travel_request/travel_request.json
@@ -490,7 +490,7 @@
    "bold": 0, 
    "collapsible": 0, 
    "columns": 0, 
-   "fieldname": "photo_id_type", 
+   "fieldname": "personal_id_type", 
    "fieldtype": "Link", 
    "hidden": 0, 
    "ignore_user_permissions": 0, 
@@ -499,10 +499,10 @@
    "in_global_search": 0, 
    "in_list_view": 0, 
    "in_standard_filter": 0, 
-   "label": "Photo ID Type", 
+   "label": "Identification Document Type", 
    "length": 0, 
    "no_copy": 0, 
-   "options": "Photo ID Type", 
+   "options": "Identification Document Type", 
    "permlevel": 0, 
    "precision": "", 
    "print_hide": 0, 
@@ -522,7 +522,7 @@
    "bold": 0, 
    "collapsible": 0, 
    "columns": 0, 
-   "fieldname": "photo_id_number", 
+   "fieldname": "personal_id_number", 
    "fieldtype": "Data", 
    "hidden": 0, 
    "ignore_user_permissions": 0, 
@@ -531,7 +531,7 @@
    "in_global_search": 0, 
    "in_list_view": 0, 
    "in_standard_filter": 0, 
-   "label": "Photo ID Number", 
+   "label": "Identification Document Number", 
    "length": 0, 
    "no_copy": 0, 
    "permlevel": 0, 
@@ -871,7 +871,7 @@
  "issingle": 0, 
  "istable": 0, 
  "max_attachments": 0, 
- "modified": "2018-05-15 10:47:54.215916", 
+ "modified": "2018-05-16 04:35:56.819570", 
  "modified_by": "Administrator", 
  "module": "HR", 
  "name": "Travel Request",
diff --git a/erpnext/hr/doctype/photo_id_type/test_photo_id_type.js b/erpnext/hr/doctype/identification_document_type/test_identification_document_type.js
similarity index 65%
rename from erpnext/hr/doctype/photo_id_type/test_photo_id_type.js
rename to erpnext/hr/doctype/identification_document_type/test_identification_document_type.js
index 738ae60..6587909 100644
--- a/erpnext/hr/doctype/photo_id_type/test_photo_id_type.js
+++ b/erpnext/hr/doctype/identification_document_type/test_identification_document_type.js
@@ -2,15 +2,15 @@
 // rename this file from _test_[name] to test_[name] to activate
 // and remove above this line
 
-QUnit.test("test: Photo ID Type", function (assert) {
+QUnit.test("test: Identification Document Type", function (assert) {
 	let done = assert.async();
 
 	// number of asserts
 	assert.expect(1);
 
 	frappe.run_serially([
-		// insert a new Photo ID Type
-		() => frappe.tests.make('Photo ID Type', [
+		// insert a new Identification Document Type
+		() => frappe.tests.make('Identification Document Type', [
 			// values to be set
 			{key: 'value'}
 		]),